package com.jh.memsource.settings;

import java.util.Objects;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.NonUniqueResultException;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import org.springframework.stereotype.Repository;

@Repository
public class SettingsRepository {

    @PersistenceContext
    private EntityManager entityManager;
    
    /**
     * Returns stored settings or null
     * 
     * @return
     */
    public Settings fetch() {
    	Query q = entityManager.createQuery("from Settings");
    	
    	try {
    		return (Settings) q.getSingleResult();
    	} catch (NoResultException e) {
    		return null;
    	} catch (NonUniqueResultException e) {
    		throw new IllegalStateException("Multiple settings records found");
    	} catch (Exception e) {
    		throw e;
    	}
    }
    
    
    /**
     * Store provided settings
     * 
     * @param settings must not be null
     */
    public void store(Settings settings) {
    	Objects.requireNonNull(settings, "Settings must not be null");
    	Settings stored = fetch();
    	if (stored == null) {
    		entityManager.persist(settings);
    		return;
    	}
    	
    	stored.setUsername(settings.getUsername());
    	stored.setPassword(settings.getPassword());
    }
    
	
}
