import React, { useState, useEffect } from 'react';

import { makeStyles } from '@material-ui/core/styles';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import Divider from '@material-ui/core/Divider';
import ListItemText from '@material-ui/core/ListItemText';
import ListItemAvatar from '@material-ui/core/ListItemAvatar';
import Avatar from '@material-ui/core/Avatar';
import WorkIcon from '@material-ui/icons/Work';
import Typography from '@material-ui/core/Typography';

import Container from '@material-ui/core/Container';
import Box from '@material-ui/core/Box';
import Paper from '@material-ui/core/Paper';

import backend from 'lib/backend';


const useStyles = makeStyles(theme => ({
	root: {
		width: '100%',
		backgroundColor: theme.palette.background.paper,
	},
	inline: {
		display: 'inline',
	},
}));


/*className={classes.inline}*/

const Project = (props) => {

	return (
		<ListItem alignItems="flex-start">
			<ListItemAvatar>
				<Avatar>
					<WorkIcon />
				</Avatar>
			</ListItemAvatar>
			<ListItemText
				primary={ props.name }
				secondary={
					<React.Fragment>
						<Typography
							component="span"
							variant="body2"
							color="textPrimary"
							>
							to Scott, Alex, Jennifer
						</Typography>
						<p>xxx</p>
					</React.Fragment>
				}
				/>
		</ListItem>
	);
}


export default (props) => {
	const classes = useStyles();
    const [ projects, setProjects ] = useState([]);
    const [ loading, setLoading ] = useState(true);

    const fetchProjects = async () => {
        setLoading(true);
        try {
            let response = await backend("/projects");
            setProjects(response.body);
        } catch (e) {
            //TODO
            setProjects(false);
        }
        setLoading(false);
    };

    useEffect(() => {
        fetchProjects();
    }, []);

    if (!Array.isArray(projects)) {
    	//an error occured
    	return <div>error</div>
    }

    //construct list items
    const list = [];
    for (let i = 0; i < projects.length; i++) {
    	list.push(<Project key={ `project-${i}` } name={ projects[i].name } />);
    	if (i < projects.length - 1) {
    		list.push(<Divider key={ `divider-${i}` } />);
    	}
    }

	return (
		<Container maxWidth="md">
			<Box m={ 2 }  className={ classes.root }>
				<Paper>
					<List>
						{ list }
					</List>
				</Paper>
			</Box>
		</Container>
	);
}